# Stringbean - a simple Python-based mud
# Copyright (C) 2004 Will Guaraldi
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

"""
This is the map for this area.  Basically, M, 1, 2, 3, 4, 5, 6, 7 and 8 
are one big room--the main room of the tavern.  E is the entrance to the 
pub.  K is the kitchen.

  5-4-3
  | | |
E-M-1-2-K
  | | |
  6-7-8
"""
from mudlib import mudlibapi
import neil
import items

NORTH = mudlibapi.NORTH
WEST = mudlibapi.WEST
SOUTH = mudlibapi.SOUTH
EAST = mudlibapi.EAST

class PubEntrance(mudlibapi.Room):
  def __init__(self):
    mudlibapi.Room.__init__(self)
    self._short = "Entrance to Neil's Pub"
    self._desc = ("This is the entrance to Neil's Pub--a small tavern of " +
            "unusual candor.  In many ways, this is a dream come true for " +
            "Neil and it shows in the care he gives to the place.  The " +
            "tavern is both infinitely large and terribly small.  There " +
            "are no exits.  Off on one end of the Pub is a kitchen.  " +
            "Between here and there is the bar, behind which Neil happily " +
            "cleans glasses, and a series of tables for you to sit down " +
            "at and take a load off.")

    self._lookables = {"kitchen": "The kitchen is on the eastern side of " +
                                  "this room.",
                       "table": "Tables are strewn about the place--wander " +
                                 "around and sit down at one.",
                       "tables": "Tables are strewn about the place--wander " +
                                 "around and sit down at one.",
                       "bar": "The bar is to the east of here.  Neil is " +
                              "happily tending to it.",
                       "pub": "This is Neil's Pub.  The care he gives the " +
                              "place shows in every nook and cranny.",
                       "tavern": "This is Neil's Pub.  The care he gives the " +
                                 "place shows in every nook and cranny."}

    self._exits = {EAST: "data.tavern.PubMain"}

    rack = items.Hatrack()
    rack.setLocation(self)

    desk = items.GuestBookDesk()
    desk.setLocation(self)

class PubMain(mudlibapi.Room):
  def __init__(self):
    mudlibapi.Room.__init__(self)
    self._short = "Pub: West side"
    self._desc = ("This is the main room of the Pub.  To the east lies the " +
                  "main bar.  The rest of the room is littered with tables.")
    self._exits = {WEST: "data.tavern.PubEntrance",
                   NORTH: "data.tavern.PubRoom5",
                   EAST: "data.tavern.PubRoom1",
                   SOUTH: "data.tavern.PubRoom6"}

    clock = items.GrandfatherClock()
    clock.setLocation(self)

class PubRoom1(mudlibapi.Room):
  def __init__(self):
    mudlibapi.Room.__init__(self)
    self._short = "Pub: Bar"
    self._desc = ("You stand at the bar of this magnificent pub.  Behind it, " +                  "Neil works happily looking up now and then to view the " +
                  "clientel.")

    self._lookables = {"bar": "The bar is a heavy oak covered in the sort " +
                              "of grime that comes with many years of use."}

    self._exits = {NORTH: "data.tavern.PubRoom4",
                   EAST: "data.tavern.PubRoom2",
                   WEST: "data.tavern.PubMain",
                   SOUTH: "data.tavern.PubRoom7"}

    neilnpc = neil.Neil()
    neilnpc.setLocation(self)

class PubRoom2(mudlibapi.Room):
  def __init__(self):
    mudlibapi.Room.__init__(self)
    self._short = "Pub: East side"
    self._desc = ("You're standing right outside the kitchen.  Best not " +
                  "stand idle here too long lest you get clipped by a " +
                  "passing serving wench on her way to fetch some food for " +
                  "a hungry tavern goer.")

    self._exits = {WEST: "data.tavern.PubRoom1",
                   NORTH: "data.tavern.PubRoom3",
                   SOUTH: "data.tavern.PubRoom8",
                   EAST: "data.tavern.PubKitchen"}


class PubRoom3(mudlibapi.Room):
  def __init__(self):
    mudlibapi.Room.__init__(self)
    self._short = "Pub: Northeast corner"
    self._desc = ("A room in the pub.")

    self._exits = {SOUTH: "data.tavern.PubRoom2",
                   WEST: "data.tavern.PubRoom4"}

    table = items.Table()
    table.setLocation(self)

class PubRoom4(mudlibapi.Room):
  def __init__(self):
    mudlibapi.Room.__init__(self)
    self._short = "Pub: North side"
    self._desc = ("A room in the pub.")

    self._exits = {SOUTH: "data.tavern.PubRoom1",
                   WEST: "data.tavern.PubRoom5",
                   EAST: "data.tavern.PubRoom3"}

    table = items.Table()
    table.setLocation(self)

class PubRoom5(mudlibapi.Room):
  def __init__(self):
    mudlibapi.Room.__init__(self)
    self._short = "Pub: Northwest corner"
    self._desc = ("A room in the pub.")

    self._exits = {SOUTH: "data.tavern.PubMain",
                   EAST: "data.tavern.PubRoom4"}

    table = items.Table()
    table.setLocation(self)

class PubKitchen(mudlibapi.Room):
  def __init__(self):
    mudlibapi.Room.__init__(self)
    self._short = "Pub: Kitchen"
    self._desc = ("The Tavern kitchen is a bit of a mess.  It's a wonder " +
                  "any food comes out of here at all.")

    self._exits = {WEST: "data.tavern.PubRoom2"}

class PubRoom6(mudlibapi.Room):
  def __init__(self):
    mudlibapi.Room.__init__(self)
    self._short = "Pub: Southwest corner"
    self._desc = ("A room in the pub.")

    self._exits = {NORTH: "data.tavern.PubMain",
                   EAST: "data.tavern.PubRoom7"}

    table = items.Table()
    table.setLocation(self)


class PubRoom7(mudlibapi.Room):
  def __init__(self):
    mudlibapi.Room.__init__(self)
    self._short = "Pub: South side"
    self._desc = ("A room in the pub.")

    self._exits = {NORTH: "data.tavern.PubRoom1",
                   EAST: "data.tavern.PubRoom8",
                   WEST: "data.tavern.PubRoom6"}

    table = items.Table()
    table.setLocation(self)


class PubRoom8(mudlibapi.Room):
  def __init__(self):
    mudlibapi.Room.__init__(self)
    self._short = "Pub: Southeast corner"
    self._desc = ("A room in the pub.")

    self._exits = {NORTH: "data.tavern.PubRoom2",
                   WEST: "data.tavern.PubRoom7"}

    table = items.Table()
    table.setLocation(self)

