# Stringbean - a simple Python-based mud
# Copyright (C) 2004 Will Guaraldi
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

"""
This module should abstract the mud from the filesystem.  This includes
(but is not limited to) handling arbitrary imports of modules (and
other data files) as well as reading and writing stuff to the file
system and whatever other data repositories we have working.

It needs to be fleshed out.

I'm thinking all object state should get saved in a ZODB rather than
pickling things and saving them to disk.  This should allow us a huge
amount of storage and give us a lot of lattitude and also not force
us to using the disk as a way of persisting data.
"""
import sys, traceback
import driverapi

def get_module(path):
  """
  Returns a module object located at "path".  Returns None if the
  module is not found.  "path" is a library module or coder-defined
  module; import system modules using "import <module>".  The full
  path must be specified (such as 'data.tavern.something').
  """
  if not sys.modules.has_key(path):
    try:
      driverapi.log("trying to import '" + path + "'")

      _module = __import__(path)
      components = path.split('.')
      for comp in components[1:]:
        _module = getattr(_module, comp)

    except Exception, e:
      traceback.print_exc()
      return None

  _module = sys.modules[path]
  setattr(_module, 'code-base', path)
  return _module

def get_class(label):
  """
  get_class(label)
  """
  path = label[:label.rfind(".")]
  ob = label[label.rfind(".")+1:]

  driverapi.log("fetching module '" + path + "'")
  _module = get_module(path)

  if _module:
    clazz = getattr(_module, ob)
    setattr(clazz, 'code-base', label)
    return clazz
  return None

def instantiate(label, args=()):
  """
  Returns an instance object instantiated from class "label".  "args"
  (optional) are passed to the constructor.  Returns None if the
  module or class is not found.

  Currently, "args" is not used.
  """
  driverapi.log("instantiating '%s'" % label)
  clazz = get_class(label)
  if clazz: 
    ob = clazz()
    if ob:

      if getattr(ob, "init", None):
        ob.init(args)

      setattr(ob, 'code_base', label)
      return ob
  return None
