# Stringbean - a simple Python-based mud
# Copyright (C) 2004 Will Guaraldi
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

"""
Managers manage things.  Most X{manager}s subclass the Manager
class.  It acts as a basic shell allowing the engine to treat them
all the same.  Managers should register with various engine hooks
to provide the functionality they need to provide.  Extending the
driver with a mudlib with mud-specific functionality is much easier
in this way.
"""
class Manager:
  """
  Base manager class for managing things in Stringbean.  The Manager class
  gives all managers a standard way of interacting with sessions and user
  queries for information, 
  """
  def __init__(self, engine):
    """
    Managers should do initialization and registration in this method.  
    Register with the L{startup<engine>} and L{shutdown<engine>} 
    hooks for the second pass at starting up (starting threads and things) 
    and for notification that the server is shutting down.
    """
    pass

  def getName(self):
    """
    Returns the name of this manager.

    @returns: the manager name
    @rtype: string
    """
    return "(none)"

  def getStatus(self):
    """
    Returns a one-liner status of the state of this manager.

    @return: a one-liner string of the status or an empty string
    @rtype: string
    """
    return ''
