# Stringbean - a simple Python-based mud
# Copyright (C) 2004 Will Guaraldi
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

"""
The mudlib package holds the mudlib classes.  These modules get loaded
when the engine calls __init__.boostrap(...).  We then import all modules
and call the I{load} method unless:

  1. the module throws an exception when getting imported
  2. the module's name starts with an _
  3. the module's name is I{world}--that's a special case that gets
     handled first
"""
import glob, os, sys
import driver.driverapi, world


def my_import(name):
  mod = __import__(name)
  components = name.split('.')
  for comp in components[1:]:
    mod = getattr(mod, comp)
  return mod


def bootstrap(my_engine):
  """
  Bootstraps the mudlib package.  This is semi-magic.

  @param my_engine: the Engine singleton object--this helps us
      register managers and hooks and such with the engine
  @type  my_engine: Engine
  """
  import world
  world.my_world = world.World(my_engine)

  # handle driver.modules.*
  index = __file__.rfind(os.sep)
  if index == -1:
    path = "." + os.sep
  else:
    path = __file__[:index]

  _module_list = glob.glob( os.path.join(path, "*.py"))
  _module_list.sort()

  for mem in _module_list:
    # we skip over all files that start with a _
    # this allows hackers to be working on a module and not have
    # it die every time.
    mem2 = mem[mem.rfind(os.sep)+1:mem.rfind(".")]
    if mem2[0] == "_" or mem2 == "world":
      continue

    try:
      name = "mudlib." + mem2
      _module = my_import(name)

      if _module.__dict__.has_key("load"):
        _module.load(my_engine, world.my_world)

      _module.__dict__["stringbean_import"] = 1
      print "Mudlib module '%s' loaded." % name
    except:
      print "Mudlib module '%s' refuses to load." % name
      driver.driverapi.print_traceback()
