# Stringbean - a simple Python-based mud
# Copyright (C) 2004 Will Guaraldi
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

"""
We hold the Message class here.  Messages can get sent around
and typically have an originator object, some kind of message, and
a data type.  We use these for spamming rooms, spamming the world,
and letting objects communicate (sort of) with each other.
"""
NONE  = -1
EVENT = 0
SAY   = 1
SHOUT = 2
EMOTE = 3

class Message:
  """
  Convenience class for passing messages around.
  """
  def __init__(self, message, datatype=NONE, originator=None, indent=0, firstline=0):
    """
    The message constructor allows for None originators as well
    empty string datatypes.

    @param message: the message string--has to either be a string or
        implement the __str__ method.
    @type  message: string

    @param originator: the mobile or other MudObject derivative that
        originated this message.  if this is None, it's assumed to
        have come from the world.
    @type  originator: MudObject or None

    @param datatype: an int representing the data category.  these
        are listed in the mudlibapi module.
    @type  datatype: int

    @param indent: how much to indent lines (for messages that need
        display)
    @type indent: int

    @param firstline: whether (1) or not (0) to indent the first line
    @type  firstline: boolean
    """
    self._orig = originator
    self._datatype = datatype
    self._message = message

    self._indent = indent
    self._firstline = firstline

  def getMessage(self):
    """
    Returns the str(self._message).

    @returns: the message string
    @rtype: string
    """
    return str(self._message)

  def __str__(self):
    return str(self._message)
