# Stringbean - a simple Python-based mud
# Copyright (C) 2004 Will Guaraldi
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

"""
World code should probably start by importing this module.  This module
provides an interface for the rest of the mudlib as well as the driver.

It also holds constants for common things allowing us to centralize
their actual values.

Documentation on the mudlib is not in the API--it should be in a separate
coders document.  Alternatively, you could just read the mudlibapi code.
"""
# FIXME - might want to either rename these message constants so
# it's clearer what they are, or move them to the driver.message module.
# message constants
import message
NONE = message.NONE
EVENT = message.EVENT
SAY = message.SAY
SHOUT = message.SHOUT
EMOTE = message.EMOTE
Message = message.Message

# directional constants
NORTH = "north"
WEST = "west"
EAST = "east"
SOUTH = "south"
SOUTHEAST = "southeast"
SOUTHWEST = "southwest"
NORTHEAST = "northeast"
NORTHWEST = "northwest"
UP = "up"
DOWN = "down"

import mobile
MALE = mobile.MALE
FEMALE = mobile.FEMALE

import utils
color = utils.color
columnize = utils.columnize
chomp = utils.chomp
random_number = utils.random_number
random_choice = utils.random_choice

import room
Room = room.Room

import mobile
NPC = mobile.NPC

import object
MudObject = object.MudObject

def add_help(name, topic):
  pass

def remove_help(name):
  pass


from driver import event, driverapi
def hook_event(hookname, argtuple):
  """
  Enqueues a HookEvent to kick off a hook with a given argtuple.

  @param hookname: the name of the hook
  @type  hookname: string

  @param argtuple: the argument tuple
  @type  argtuple: varies
  """
  event.HookEvent(hookname, argtuple).enqueue()

timedeventmanager = None

def register_hb(ob):
  """
  Registers an object with a heartbeat with the timedeventmanager which 
  handles heartbeat things.
  """
  global timedeventmanager
  if timedeventmanager == None:
    timedeventmanager = driverapi.get_engine().getManager("timedevent")
  timedeventmanager.registerHeartbeat(ob)

def unregister_hb(ob):
  """
  Unregisters an object with a heartbeat with the timedeventmanager which 
  handles heartbeat things.
  """
  global timedeventmanager
  if timedeventmanager == None:
    timedeventmanager = driverapi.get_engine().getManager("timedevent")
  timedeventmanager.unregisterHeartbeat(ob)

def callout(tickoffset, f, *nargs, **kargs):
  """
  Creates a callout at tickoffset seconds from now and executes function f
  with arguments *nargs and keyword arguments **kargs.
  """
  global timedeventmanager
  if timedeventmanager == None:
    timedeventmanager = driverapi.get_engine().getManager("timedevent")
  timedeventmanager.callout(tickoffset, f, *nargs, **kargs)

global_world = None

def get_world():
  return global_world

def load(my_engine, my_world):
  global global_world
  global_world = my_world
