#!/usr/bin/python
"""
Starts up Stringbean.
"""
import sys, traceback, os

_my_engine = None

def print_syntax(message=""):
  print "startup.py [--help] [options]"
  print "    -h|--host <hostname>   - sets the hostname to bind to"
  print "    -p|--port <port>       - sets the port to bind to (default 3000)"
  print "    -s|--startroom <room>  - sets the start room"
  print "    -v|--verbose           - verbose logging to stdout"
  print "    -m|--mudlib <package>  - the package for the mudlib"
  print
  if message:
    print message

def shutdown():
  import startup
  if startup._my_engine != None:
    startup._my_engine.shutdown()

if __name__ == '__main__':
  import startup, driver.engine, driver.network, driver.utils

  import atexit
  atexit.register(startup.shutdown)

  # parse out arguments
  optlist = driver.utils.parse_args(sys.argv[1:])

  options = {"host": "localhost", 
             "port": "3000", 
             "heartbeat": "yes", 
             "verbose": 0, 
             "startroom": "data.tavern.PubEntrance",
             "mudlib": []}

  for mem in optlist:
    if mem[0] == "--host" or mem[0] == "-h":
      if mem[1]:
        options["host"] = mem[1]
      else:
        print_syntax("error: Host was not specified.")
        sys.exit(1)

    elif mem[0] == "--help":
      print_syntax()
      sys.exit(1)

    elif mem[0] == "--verbose":
      options["verbose"] = 1

    elif mem[0] == "--mudlib" or mem[0] == "-m":
      if mem[1] and os.stat(mem[1]):
        options["mudlib"].append(mem[1])
      else:
        print_syntax("error: mudlib needs a package argument")
        sys.exit(1)

    elif mem[0] == "--port" or mem[0] == "-p":
      if mem[1] and mem[1].isdigit():
        options["port"] = mem[1]
      else:
        print_syntax("error: Port needs to be a number.")
        sys.exit(1)

    elif mem[0] == "--startroom" or mem[0] == "-s":
      if mem[1]:
        options["startroom"] = mem[1]
      else:
        print_syntax("error: Start room was not specified.")
        sys.exit(1)

    elif mem[0] == "--heartbeat":
      if mem[1].lower() == "yes" or mem[1].lower() == "no":
        options["heartbeat"] = mem[1].lower()
      else:
        print_syntax("error: Valid heartbeat settings are 'yes' or 'no'.")
        sys.exit(1)

  if len(options["mudlib"]) == 0:
    print_syntax("error: requires a mudlib argument to work.")
    sys.exit(1)

  # create the engine
  startup._my_engine = driver.engine.get_engine()
  startup._my_engine.setOptions(options)
  try:
    startup._my_engine.startup()

  except KeyboardInterrupt:
    print "System exit."
    sys.exit(1)

  except SystemExit:
    print "System exit."
    sys.exit(1)

  except Exception, e:
    print "Outer loop exception: %s" % e
    traceback.print_exc()
    sys.exit(1)
